--- file.c.0	Mon Feb 14 08:29:58 2000
+++ file.c	Mon Feb 14 08:32:14 2000
@@ -19,9 +19,9 @@
 #endif
 
 static struct file_operations bfs_file_operations = {
-	read:			generic_file_read,
-	write:			generic_file_write,
-	mmap:			generic_file_mmap,
+	read:	generic_file_read,
+	write:	generic_file_write,
+	mmap:	generic_file_mmap,
 };
 
 static int bfs_move_block(unsigned long from, unsigned long to, kdev_t dev)
@@ -77,7 +77,8 @@
 	/* if the file is not empty and the requested block is within the range
 	   of blocks allocated for this file, we can grant it */
 	if (inode->i_size && phys <= inode->iu_eblock) {
-		dprintf("c=%d, b=%08lx, phys=%08lx (interim block granted)\n", create, block, phys);
+		dprintf("c=%d, b=%08lx, phys=%08lx (interim block granted)\n", 
+				create, block, phys);
 		bh_result->b_dev = inode->i_dev;
 		bh_result->b_blocknr = phys;
 		bh_result->b_state |= (1UL << BH_Mapped);
@@ -90,7 +91,8 @@
 	/* if the last data block for this file is the last allocated block, we can
 	   extend the file trivially, without moving it anywhere */
 	if (inode->iu_eblock == s->su_lf_eblk) {
-		dprintf("c=%d, b=%08lx, phys=%08lx (simple extension)\n", create, block, phys);
+		dprintf("c=%d, b=%08lx, phys=%08lx (simple extension)\n", 
+				create, block, phys);
 		bh_result->b_dev = inode->i_dev;
 		bh_result->b_blocknr = phys;
 		bh_result->b_state |= (1UL << BH_Mapped);
@@ -104,9 +106,10 @@
 	/* Ok, we have to move this entire file to the next free block */
 	next_free_block = s->su_lf_eblk + 1;
 	if (inode->iu_sblock) { /* if data starts on block 0 then there is no data */
-		err = bfs_move_blocks(inode->i_dev, inode->iu_sblock, inode->iu_eblock, next_free_block);
+		err = bfs_move_blocks(inode->i_dev, inode->iu_sblock, 
+				inode->iu_eblock, next_free_block);
 		if (err) {
-			dprintf("failed to move ino=%08lx -> possible fs corruption\n", inode->i_ino);
+			dprintf("failed to move ino=%08lx -> fs corruption\n", inode->i_ino);
 			goto out;
 		}
 	} else
@@ -126,26 +129,30 @@
 
 static int bfs_writepage(struct dentry *dentry, struct page *page)
 {
-	return block_write_full_page(page,bfs_get_block);
+	return block_write_full_page(page, bfs_get_block);
 }
+
 static int bfs_readpage(struct dentry *dentry, struct page *page)
 {
-	return block_read_full_page(page,bfs_get_block);
+	return block_read_full_page(page, bfs_get_block);
 }
+
 static int bfs_prepare_write(struct page *page, unsigned from, unsigned to)
 {
-	return block_prepare_write(page,from,to,bfs_get_block);
+	return block_prepare_write(page, from, to, bfs_get_block);
 }
+
 static int bfs_bmap(struct address_space *mapping, long block)
 {
-	return generic_block_bmap(mapping,block,bfs_get_block);
+	return generic_block_bmap(mapping, block, bfs_get_block);
 }
+
 struct address_space_operations bfs_aops = {
-	readpage: bfs_readpage,
-	writepage: bfs_writepage,
-	prepare_write: bfs_prepare_write,
-	commit_write: generic_commit_write,
-	bmap: bfs_bmap
+	readpage:	bfs_readpage,
+	writepage:	bfs_writepage,
+	prepare_write:	bfs_prepare_write,
+	commit_write:	generic_commit_write,
+	bmap:		bfs_bmap
 };
 
 struct inode_operations bfs_file_inops = {
